@@ -152,7 +152,7 @@ class XGO():
     communication interface between the upper computer and the machine dog
     """
 
-    def __init__(self, port, baud=115200, version='xgomini'):
+    def __init__(self, port, baud=115200, version='xgolite'):
         self.ser = serial.Serial(port, baud, timeout=0.5)
         self.rx_FLAG = 0
         self.rx_COUNT = 0
@@ -193,6 +193,10 @@ class XGO():
         self.move_y(0)
         self.mark_time(0)
         self.turn(0)
+        for i in ['x','y','z']:
+            self.periodic_tran(i,0)
+        for i in ['r','p','y']:
+            self.periodic_rot(i, 0)
 
     def move(self, direction, step):
         if direction in ['x', 'X']:
